@@ -59,6 +59,8 @@ static bool have_createdb_privilege(void);
 static void remove_dbtablespaces(Oid db_id);
 static bool check_db_file_conflict(Oid db_id);
 
+/* For Sigres */
+extern bool enableSigres;
 
 /*
  * CREATE DATABASE
@@ -504,9 +506,9 @@ createdb(const CreatedbStmt *stmt)
 		 * Perhaps if we ever implement CREATE DATABASE in a less cheesy way,
 		 * we can avoid this.
 		 */
-#ifndef SIGRES
-		RequestCheckpoint(true, false);
-#endif
+		if (enableSigres == false)
+			RequestCheckpoint(true, false);
+
 		/*
 		 * Close pg_database, but keep lock till commit (this is important to
 		 * prevent any risk of deadlock failure while updating flat file)
