@@ -62,13 +62,14 @@
 #include "utils/memutils.h"
 #include "utils/resowner.h"
 
-#ifdef SIGRES
 #include "debug.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-extern int BgWriterPid; /* Entity is in "globals.c" */
-#endif
+
+/* For Sigres */
+extern int BgWriterPid;   /* Entity is in "globals.c" */
+extern bool enableSigres; /* Entity is in "globals.c" */
 
 /*----------
  * Shared memory area for communication between bgwriter and backends
@@ -177,7 +178,7 @@ BackgroundWriterMain(void)
 	BgWriterShmem->bgwriter_pid = MyProcPid;
 	am_bg_writer = true;
 
-#ifdef SIGRES
+	if (enableSigres == true)
   {
     int fd;
 
@@ -186,7 +187,6 @@ BackgroundWriterMain(void)
     if (close(fd) == -1) ERR;
     BgWriterPid = MyProcPid;
   }
-#endif
 
 	/*
 	 * If possible, make this process a group leader, so that the postmaster
@@ -338,23 +338,23 @@ BackgroundWriterMain(void)
 	 */
 	PG_SETMASK(&UnBlockSig);
 
-#ifdef SIGRES
-  for (;;) {
-    if (!PostmasterIsAlive(true))
-      exit(1);
+	if (enableSigres == true) {
+		for (;;) {
+			if (!PostmasterIsAlive(true))
+				exit(1);
 
-    /*
-     * Process any requests or signals received recently.
-     */
-    AbsorbFsyncRequests();
+			/*
+			 * Process any requests or signals received recently.
+			 */
+			AbsorbFsyncRequests();
 
-    if (got_SIGHUP)
-		{
+			if (got_SIGHUP)
+			{
 				got_SIGHUP = false;
 				ProcessConfigFile(PGC_SIGHUP);
-		}
-    if (shutdown_requested)
-		{
+			}
+			if (shutdown_requested)
+			{
 				/*
 				 * From here on, elog(ERROR) should end with exit(1), not send
 				 * control back to the sigsetjmp block above
@@ -363,13 +363,16 @@ BackgroundWriterMain(void)
 				/* Close down the database */
 				ShutdownXLOG(0, 0);
 				DumpFreeSpaceMap(0, 0);
+
+				remove(BGWRITER_PIDFILE);  /* SIGRES */
+
 				/* Normal exit from the bgwriter is here */
 				proc_exit(0);   /* done */
-		}
+			}
 
-    usleep(100000L);
-  }
-#endif
+			usleep(100000L);
+		}
+	}
 
 	/*
 	 * Loop forever
@@ -556,7 +559,6 @@ BackgroundWriterMain(void)
 	}
 }
 
-
 /* --------------------------------
  *		signal handler routines
  * --------------------------------
